@@ -3,6 +3,7 @@
 #
 # Support.pm
 # Copyright (C) 1991-2007 by John Heidemann <johnh@isi.edu>
+# $Id$
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -24,20 +25,18 @@ This class contains the bits of Fsdb::Old that needed to be kept.
 =cut
 
 @ISA = ();
-($VERSION) = 1.0;
+($VERSION) = ('$Revision$' =~ m/(\d+)/);
 
 ## Module import.
 use Exporter 'import';
 @EXPORT = qw();
 @EXPORT_OK = qw(
-    shell_quote
     code_prettify
     force_numeric
     fullname_to_sortkey
     progname
     $is_numeric_regexp
     ddmmmyy_to_iso
-    int_to_metric
     );
 
 #
@@ -99,45 +98,11 @@ Convert db-code into "pretty code".
 
 =cut
 sub code_prettify (@) {
-    my($prettycode) = join(";", @_);
+    local($prettycode) = join(";", @_);
     $prettycode =~ s/\n/ /g;   # newlines will break commenting
     return $prettycode;
 }
 
-=head2 shell_quote
-
-Convert output to shell-like quoting
-
-=cut
-sub shell_quote(@) {
-    my($s) = @_;
-    if ($s =~ /\s/) {
-	# should use String::ShellQuote, but don't want the dpeendency
-	$s =~ s/\'/'\\\''/g;
-	$s = "'" . $s . "'";
-    };
-    return $s;
-}
-
-=head1 CONVERSION FUNCTIONS
-
-=head2 number_prettify 
-
-Add-thousands-separators to numbers.
-
-xxx: should consider locale.
-
-(This code is from F<http://www.perlmonks.org/?node_id=653>,
-contributed by Andrew Johnson from University of Alberta.)
-
-=cut
-sub number_prettify($) {
-	my $input = shift;
-        $input = reverse $input;
-        $input =~ s<(\d\d\d)(?=\d)(?!\d*\.)><$1,>g;
-        return reverse $input;
-}
-
 =head2 force_numeric
 
     my $x = force_numeric($s, $include_non_numeric)
@@ -213,25 +178,4 @@ sub ddmmmyy_to_iso {
     return sprintf("%04d-%02d-%02d", $yyyy, $mm, $dd);
 }
 
-=head2 int_to_metric
-
-    my $value_str = int_to_metric(1000000);
-
-Converts an integer into a string with its metric abbreviation.
-
-1000 => 1k
-1000000 => 1M
-
-=cut
-sub int_to_metric {
-    my($n) = @_;
-    my($prefix) = " kMGTEP";
-    while (length($prefix) > 1) {
-        last if ($n < 10000);
-        $n = int($n / 1000);
-        $prefix = substr($prefix, 1);
-    };
-    return "$n" . substr($prefix, 0, 1);
-}
-
 1;
